@@ -6,7 +6,7 @@ use JSON::PP;
 use List::Util qw(sum min max);
 use Scalar::Util qw(looks_like_number);
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 sub new {
     my ($class, %opts) = @_;
@@ -206,6 +206,26 @@ sub run_query {
             next;
         }
 
+        # support for product
+        if ($part eq 'product') {
+            @next_results = map {
+                if (ref $_ eq 'ARRAY') {
+                    my $product    = 1;
+                    my $has_values = 0;
+                    for my $val (@$_) {
+                        next unless defined $val;
+                        $product *= (0 + $val);
+                        $has_values = 1;
+                    }
+                    $has_values ? $product : 1;
+                } else {
+                    $_;
+                }
+            } @results;
+            @results = @next_results;
+            next;
+        }
+
         # support for min
         if ($part eq 'min') {
             @next_results = map {
@@ -525,6 +545,17 @@ sub run_query {
             next;
         }
 
+        # support for replace(old, new)
+        if ($part =~ /^replace\((.+)\)$/) {
+            my ($search, $replacement) = _parse_arguments($1);
+            $search      = defined $search      ? $search      : '';
+            $replacement = defined $replacement ? $replacement : '';
+
+            @next_results = map { _apply_replace($_, $search, $replacement) } @results;
+            @results = @next_results;
+            next;
+        }
+
         # support for split("separator")
         if ($part =~ /^split\((.+)\)$/) {
             my $separator = _parse_string_argument($1);
@@ -988,6 +1019,28 @@ sub _apply_substr {
     return substr($value, $start);
 }
 
+sub _apply_replace {
+    my ($value, $search, $replacement) = @_;
+
+    if (ref $value eq 'ARRAY') {
+        return [ map { _apply_replace($_, $search, $replacement) } @$value ];
+    }
+
+    return $value if !defined $value;
+    return $value if ref $value;
+
+    return $value if looks_like_number($value);
+
+    $search      = defined $search      ? "$search"      : '';
+    $replacement = defined $replacement ? "$replacement" : '';
+
+    return $value if $search eq '';
+
+    my $pattern = quotemeta $search;
+    (my $copy = "$value") =~ s/$pattern/$replacement/g;
+    return $copy;
+}
+
 sub _parse_arguments {
     my ($raw) = @_;
 
@@ -1109,7 +1162,7 @@ JQ::Lite - A lightweight jq-like JSON query engine in Perl
 
 =head1 VERSION
 
-Version 0.58
+Version 0.59
 
 =head1 SYNOPSIS
 
@@ -1146,7 +1199,7 @@ jq-like syntax — entirely within Perl, with no external binaries or XS modules
 
 =item * Pipe-style query chaining using | operator
 
-=item * Built-in functions: length, keys, values, first, last, reverse, sort, sort_by, unique, has, contains, group_by, group_count, join, split, count, empty, type, nth, del, compact, upper, lower, abs, ceil, floor, trim, substr, startswith, endswith, add, sum, min, max, avg, median
+=item * Built-in functions: length, keys, values, first, last, reverse, sort, sort_by, unique, has, contains, group_by, group_count, join, split, count, empty, type, nth, del, compact, upper, lower, abs, ceil, floor, trim, substr, startswith, endswith, add, sum, product, min, max, avg, median
 
 =item * Supports map(...) and limit(n) style transformations
 
